#
# spec file for package amazon-ssm-agent
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           amazon-ssm-agent
Version:        2.2.45.0
Release:        2.3.1
Summary:        Amazon Remote System Config Management
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/aws/amazon-ssm-agent
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}.service
Patch1:         fix-config.patch
Patch2:         fix-version.patch
BuildRequires:  go >= 1.7.4
BuildRequires:  systemd
Requires:       systemd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides the Amazon SSM Agent for managing EC2 Instances using
Amazon EC2 Systems Manager (SSM).

The SSM Agent runs on EC2 or on-premise instances and enables you to quickly
and easily execute remote commands or scripts against one or more instances.
When you execute a command, the agent on the instance processes the document
and configures the instance as specified.

This collection of capabilities helps you automate management tasks such as
collecting system inventory, applying operating system (OS) patches, automating
the creation of Amazon Machine Images (AMIs), and configuring operating systems
(OSs) and applications at scale. Systems Manager works with managed instances:
Amazon EC2 instances, or servers and virtual machines (VMs) in your on-premises
environment that are configured for Systems Manager.

%prep
%setup -q -n %{name}-%{version}
%patch1 -p1
%patch2 -p1

%build
rm -rf vendor/src/github.com/aws/aws-sdk-go/vendor/

mkdir -p src/github.com/aws/amazon-ssm-agent
mv Tools agent vendor makefile amazon-ssm-agent.json.template \
seelog_unix.xml packaging src/github.com/aws/amazon-ssm-agent/

PKG_ROOT=`pwd`/src/github.com/aws/amazon-ssm-agent
GOPATH=${PKG_ROOT}/vendor:`pwd`
export GOPATH

go build -ldflags "-s -w" -o bin/amazon-ssm-agent -v \
${PKG_ROOT}/agent/agent.go \
${PKG_ROOT}/agent/agent_unix.go \
${PKG_ROOT}/agent/agent_parser.go

go build -ldflags "-s -w" -o bin/ssm-cli -v \
${PKG_ROOT}/agent/cli-main/cli-main.go

go build -ldflags "-s -w" -o bin/ssm-document-worker -v \
${PKG_ROOT}/agent/framework/processor/executer/outofproc/worker/main.go

%install
install -d -m 755 %{buildroot}%{_sbindir}
install -d -m 755 %{buildroot}%{_bindir}
install -d -m 755 %{buildroot}%{_sysconfdir}/init
install -d -m 755 %{buildroot}%{_sysconfdir}/amazon/ssm
install -m 755 bin/amazon-ssm-agent %{buildroot}%{_sbindir}
install -m 755 bin/ssm-cli %{buildroot}%{_bindir}
install -m 755 bin/ssm-document-worker %{buildroot}%{_bindir}

mkdir -p %{buildroot}%{_unitdir}
install -m 755 %SOURCE1 %{buildroot}%{_unitdir}

PKG_ROOT=`pwd`/src/github.com/aws/amazon-ssm-agent
cp ${PKG_ROOT}/seelog_unix.xml %{buildroot}/etc/amazon/ssm/seelog.xml.template
cp ${PKG_ROOT}/amazon-ssm-agent.json.template %{buildroot}/etc/amazon/ssm/
cp ${PKG_ROOT}/packaging/linux/amazon-ssm-agent.conf %{buildroot}/etc/init/

%files
%defattr(-,root,root,-)
%dir %{_sysconfdir}/init
%dir %{_sysconfdir}/amazon
%dir %{_sysconfdir}/amazon/ssm
%doc CONTRIBUTING.md LICENSE NOTICE.md README.md
%config(noreplace) %{_sysconfdir}/init/amazon-ssm-agent.conf
%config(noreplace) %{_sysconfdir}/amazon/ssm/amazon-ssm-agent.json.template
%config(noreplace) %{_sysconfdir}/amazon/ssm/seelog.xml.template
%{_sbindir}/*
%{_bindir}/*
%{_unitdir}/%{name}.service

%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post
%service_add_post %{name}.service

%postun
%service_del_postun %{name}.service

%changelog
* Mon Nov 27 2017 sean.marlow@suse.com
- Update Go version requirement to 1.7.4.
* Wed Nov  8 2017 sean.marlow@suse.com
- Add ssm-document-worker binary to agent package.
* Wed Nov  8 2017 sean.marlow@suse.com
- Update to 2.2.45.0 2017-10-18 (bsc#1067256)
  + Refresh version patch with new version.
  + Adding versioning support for Parameter Store.
  + Added additional gatherers for inventory, including windows
    service gatherer, windows registry gatherer, file metadata
    gatherer, windows role gatherer.
  + Added support for aws:downloadContent plugin to download
    content from GitHub, S3 and documents from SSM documents.
  + Added support for aws:runDocument plugin to execute SSM
    documents.
- Update to 2.2.30.0 2017-10-09
  + Improved speed of initial association application on boot
  + Various aws:configurePackage service integration changes
  + Improved home directory detection in non-x64 linux platforms
    to address cases where shared AWS SDK credentials were not
    available in on-prem instances
- Update to 2.2.24.0 2017-10-02
  + Added exponential backoff in bucket region check for s3 upload
  + Fixed an issue with orchestration directory cleanup for
    RunCommand
- Update to 2.2.16.0 2017-09-25
- Update to 2.1.4.0 2017-09-11
  + Support for command execution out-of-process
- Update to 2.0.952.0 2017-08-28
* Fri Aug 25 2017 sean.marlow@suse.com
- Add ssm-cli to package.
- Remove requirement on lsb-release. Agent now parses os-release
  by default.
- Use gzip archive from GitHub instead of converting to xz.
- Update to 2.0.922.0 2017-08-14 (bsc#1055766)
  + Added Raspbian support for armv6 to support Raspberry Pi
  + Various bug fixes
- Update to 2.0.913.0 2017-08-07
  + Updated golang/sys dependency to the latest
  + Increased run command document maximum execution timeout to 48 hours
  + Various bug fixes
- Update to 2.0.902.0 2017-07-31
  + Added support for uploading agent logs to CloudWatch for SSM Agent diagnostics
  + Added additional gatherers for inventory
  + Added configuration compliance support for association
  + Various bug fixes
- Update to 2.0.879.0 2017-07-26
  + Add capability to configure custom s3 endpoint for the agent
  + Various bug fixes
- Update to 2.0.847.0 2017-07-03
  + Various bug fixes
- Update to 2.0.842.0 2017-06-26
  + Added rollback support in aws:configurePackage
  + Various bug fixes
- Update to 2.0.834.0 2017-06-23
  + Various bug fixes
- Update to 2.0.805.0 2017-06-07
  + Added support for SLES (SUSE) (64-bit, v12 and above)
  + Various bug fixes
- Update to 2.0.796.0 2017-05-29
  + Linux platform version now based on os-release when available
  + Various bug fixes
* Wed May 31 2017 sean.marlow@suse.com
- Update to 2.0.790.0 2017-05-31 (bsc#1047581)
  - Added support for step-level preconditions
  - Added support for rate/interval based schedule expressions for
    associations
  - Added Summary and PackageID fields to inventory's
    aws:application gatherer
  - Changed inventory's aws:application gatherer to use
    win32_processor: addressWidth to detect OS architecture to
    avoid localization based errors
  - Fixed CloudWatch issue with large configuration
  - Fixed S3 upload when instance and bucket are not in the same
    region
  - Fixed bug that prevented native language AMIs (Japanese AMI)
    from launching Cloudwatch
  - Various bug fixes
- Update to 2.0.767.0 2017-05-31
  - Returning longer StandardOutput and StandardError from
    RunShellScript and RunPowerShellScript which show up in the
    results of GetCommandInvocation and the detailed output of
    ListCommandInvocation
  - Added Document v2.0 support for Run Command, which includes
    support for multiple actions of same plugin type
  - Various bug fixes
- Update to 2.0.755.0 2017-05-31
  - Fixed bugs that prevented CloudWatch from launching and allowed
    multiple instances of CloudWatch to launch on Windows
  - Various bug fixes
- Update to 2.0.730.0 2017-05-31
  - Fixed issues with agent starting before network is ready on
    systemd systems.
- Update to 2.0.716.0 2017-05-31
  - Pass proxy settings to domain join and CloudWatch
  - Added support for installing Docker on Linux
  - Removed the upper limit for the maximum number of parallel
    executing documents on the agent (previously the max was 10)
  - You can configure this number by setting the
    “CommandWorkerLimit” attribute in amazon-ssm-agent.json file
  - Various bug fixes
* Wed Mar  1 2017 lchiquitto@suse.de
- Add package to SLE-12 codestream (bsc#1017899, fate#322303)
* Fri Feb 17 2017 sean.marlow@suse.com
- Update to 2.0.672.0 2017-02-17
  - Added bucket-owner-full-control ACL to S3 outputs to support
    cross-account upload
  - Standardized S3 result paths across plugins; commands append
    command-id/instance-id/plugin-name/step-id associations append
    instance-id/association-id/execution-date/plugin-name/step-id
  - step-id is the id field in plugin input if present and
    supported, otherwise the step name (in 2.0 schema documents),
    otherwise the plugin-name again
  - plugin-name and step-id have : characters removed
  - FreeBSD patches from external contributor
  - Various bug fixes
* Thu Jan 19 2017 sean.marlow@suse.com
- Update to 2.0.663.0 2017-01-18
  - Added support for aws:softwareInventory plugin to upload
    inventory related log messages to S3
  - Added support for running Powershell on Linux
  - Added support for State Manager that automates the process of
    keeping your Amazon EC2 and hybrid infrastructure in a state that
    you define You can use State Manager to ensure that your instances
    are bootstrapped with specific software at startup, configured
    according to your security policy, joined to a Windows domain,
    or patched with specific software updates throughout their
    lifecycle
  - Added support for Systems Manager Inventory that allows you to
    specify the type of metadata to collect, the instances from
    where the metadata should be collected, and a schedule for
    metadata collection
  - Added support for installing, uninstalling, and updating AWS
    packages published by AWS
  - Added support for installing Docker on Windows and running
    Docker actions
  - Added support for Windows Server 2016
  - Added support for Windows Server Nano
  - Fixed CloudWatch crash issue
  - Fixed Domain Join to support customized OU
  - Fixed CloudWatch doesn't work with creating association from
    Console
  - Fixed SSM Agent not able to start on Windows Server 2003
  - Various bug fixes
* Fri Dec 16 2016 sean.marlow@suse.com
- Initial package 1.2.290.0 2016-07-20
